@@ -41,6 +41,7 @@ class GitLabCore:
             cli_ui.debug(
                 f"Connected to GitLab version: {version['version']} ({version['revision']})"
             )
+            self.version = version["version"]
         except Exception as e:
             raise TestRequestFailedException(e)
 
@@ -196,11 +197,13 @@ class GitLabCore:
             )
         logging.debug("response code=%s" % response.status_code)
 
-        if response.status_code == 204:
-            # code calling this function assumes that it can do response.json() so fake it to return empty dict
-            response.json = lambda: {}
-
-        if response.status_code not in expected_codes:
+        if response.status_code in expected_codes:
+            # if we accept error responses then they will likely not contain a JSON body
+            # so fake it to fix further calls to response.json()
+            if response.status_code == 204 or (400 <= response.status_code <= 499):
+                logging.debug("faking response body to be {}")
+                response.json = lambda: {}
+        else:
             if response.status_code == 404:
                 raise NotFoundException("Resource path='%s' not found!" % url)
             else:
