@@ -331,6 +331,9 @@ class GitLabFormCore(object):
         if len(groups) == 0 and len(projects) == 0:
             cli_ui.error(f"Entity {self.project_or_group} cannot be found in GitLab!")
             sys.exit(EXIT_INVALID_INPUT)
+        else:
+            cli_ui.debug(f"groups: {groups}")
+            cli_ui.debug(f"projects: {projects}")
 
         cli_ui.info_1(f"# of groups to process: {len(groups)}")
         cli_ui.info_1(f"# of projects to process: {len(projects)}")
@@ -359,7 +362,7 @@ class GitLabFormCore(object):
                 # so ensure that such group exists
                 try:
                     group = self.gitlab.get_group_case_insensitive(group)
-                    effective_groups_proper_case.append(group["path"])
+                    effective_groups_proper_case.append(group["full_path"])
                 except NotFoundException:
                     cli_ui.error(
                         f"Configuration contains group {group} but it cannot be found in GitLab!"
@@ -371,7 +374,7 @@ class GitLabFormCore(object):
         try:
             # it may be a subgroup or a single group
             maybe_group = self.gitlab.get_group_case_insensitive(request_query)
-            return [maybe_group["path"]]
+            return [maybe_group["full_path"]]
         except NotFoundException:
             return []
 
@@ -385,8 +388,6 @@ class GitLabFormCore(object):
 
         if request_query == "ALL_DEFINED":
             # get projects explicitly defined in the configuration,
-            # but add them to the projects from groups,
-            # and finally remove the skipped ones
             requested_projects = self.configuration.get_projects()
 
         else:
@@ -397,6 +398,7 @@ class GitLabFormCore(object):
             except NotFoundException:
                 pass
 
+        # get the projects from the groups to process
         projects_from_groups = self._get_projects_from_groups(groups)
 
         # casting to set and back to list to deduplicate
